summaryrefslogtreecommitdiffstats
path: root/tdeio/tdeio
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 12:03:00 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-09-25 17:50:49 +0900
commit04d353236066b9aa85f6387fa05d3d37b75a7dd2 (patch)
tree3781200cbdb5db08e22cb07dd16c2dcdf6402b98 /tdeio/tdeio
parentb0f1961286230520573e2433b0ed4562718ce7a3 (diff)
downloadtdelibs-04d353236066b9aa85f6387fa05d3d37b75a7dd2.tar.gz
tdelibs-04d353236066b9aa85f6387fa05d3d37b75a7dd2.zip
Replace QObject, QWidget, QImage, QPair, QRgb, QColor, QChar, QString, QIODevice with TQ* version
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it> (cherry picked from commit 4c0dae60b2fbc60996fc8f4bd29ee6219b869527)
Diffstat (limited to 'tdeio/tdeio')
-rw-r--r--tdeio/tdeio/kacl.cpp6
-rw-r--r--tdeio/tdeio/kacl.h8
-rw-r--r--tdeio/tdeio/kmimetyperesolver.h2
-rw-r--r--tdeio/tdeio/kscan.h16
-rw-r--r--tdeio/tdeio/kurifilter.h2
-rw-r--r--tdeio/tdeio/tdefilemetainfo.h2
6 files changed, 18 insertions, 18 deletions
diff --git a/tdeio/tdeio/kacl.cpp b/tdeio/tdeio/kacl.cpp
index fcf3cc13f..b62ac5438 100644
--- a/tdeio/tdeio/kacl.cpp
+++ b/tdeio/tdeio/kacl.cpp
@@ -62,7 +62,7 @@ public:
bool setMaskPermissions( unsigned short v );
TQString getUserName( uid_t uid ) const;
TQString getGroupName( gid_t gid ) const;
- bool setAllUsersOrGroups( const TQValueList< QPair<TQString, unsigned short> > &list, acl_tag_t type );
+ bool setAllUsersOrGroups( const TQValueList< TQPair<TQString, unsigned short> > &list, acl_tag_t type );
bool setNamedUserOrGroupPermissions( const TQString& name, unsigned short permissions, acl_tag_t type );
acl_t m_acl;
@@ -429,7 +429,7 @@ ACLUserPermissionsList KACL::allUserPermissions() const
}
#ifdef USE_POSIX_ACL
-bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< QPair<TQString, unsigned short> > &list, acl_tag_t type )
+bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< TQPair<TQString, unsigned short> > &list, acl_tag_t type )
{
bool allIsWell = true;
bool atLeastOneUserOrGroup = false;
@@ -456,7 +456,7 @@ bool KACL::KACLPrivate::setAllUsersOrGroups( const TQValueList< QPair<TQString,
//printACL( newACL, "After cleaning out entries: " );
// now add the entries from the list
- TQValueList< QPair<TQString, unsigned short> >::const_iterator it = list.constBegin();
+ TQValueList< TQPair<TQString, unsigned short> >::const_iterator it = list.constBegin();
while ( it != list.constEnd() ) {
acl_create_entry( &newACL, &entry );
acl_set_tag_type( entry, type );
diff --git a/tdeio/tdeio/kmimetyperesolver.h b/tdeio/tdeio/kmimetyperesolver.h
index 655b1e3d1..b36d1ffb2 100644
--- a/tdeio/tdeio/kmimetyperesolver.h
+++ b/tdeio/tdeio/kmimetyperesolver.h
@@ -42,7 +42,7 @@ protected:
/**
* @internal
- * This class is used by KMimeTypeResolver, because it can't be a QObject
+ * This class is used by KMimeTypeResolver, because it can't be a TQObject
* itself. So an object of this class is used to handle signals, slots etc.
* and forwards them to the KMimeTypeResolver instance.
*/
diff --git a/tdeio/tdeio/kscan.h b/tdeio/tdeio/kscan.h
index 450a5ca45..eb9ab9116 100644
--- a/tdeio/tdeio/kscan.h
+++ b/tdeio/tdeio/kscan.h
@@ -70,7 +70,7 @@ public:
* or 0L if no scan-support
* is available. Pass a suitable @p parent widget, if you like. If you
* don't you have to 'delete' the returned pointer yourself.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
* @return the KScanDialog, or 0 if the function failed
@@ -100,7 +100,7 @@ protected:
* @param dialogFace the KDialogBase::DialogType
* @param buttonMask a ORed mask of all buttons (see
* KDialogBase::ButtonCode)
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
* @see KDialogBase
@@ -187,7 +187,7 @@ public:
/**
* Your library should reimplement this method to return your KScanDialog
* derived dialog.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
*/
@@ -197,7 +197,7 @@ public:
protected:
/**
* Creates a new KScanDialogFactory.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
*/
KScanDialogFactory( TQObject *parent=0, const char *name=0 );
@@ -243,7 +243,7 @@ public:
* or 0L if no OCR-support
* is available. Pass a suitable @p parent widget, if you like. If you
* don't you have to 'delete' the returned pointer yourself.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
* @return the KOCRDialog, or 0 if the function failed
@@ -260,7 +260,7 @@ protected:
* @param dialogFace the KDialogBase::DialogType
* @param buttonMask a ORed mask of all buttons (see
* KDialogBase::ButtonCode)
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
*/
@@ -323,7 +323,7 @@ public:
/**
* Your library should reimplement this method to return your KOCRDialog
* derived dialog.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
* @param modal if true the dialog is model
*/
@@ -333,7 +333,7 @@ public:
protected:
/**
* Creates a new KScanDialogFactory.
- * @param parent the QWidget's parent, or 0
+ * @param parent the TQWidget's parent, or 0
* @param name the name of the TQObject, can be 0
*/
KOCRDialogFactory( TQObject *parent=0, const char *name=0 );
diff --git a/tdeio/tdeio/kurifilter.h b/tdeio/tdeio/kurifilter.h
index dfc686821..3c6861c15 100644
--- a/tdeio/tdeio/kurifilter.h
+++ b/tdeio/tdeio/kurifilter.h
@@ -306,7 +306,7 @@ public:
/**
* Overloaded assigenment operator.
*
- * This function allows you to easily assign a QString
+ * This function allows you to easily assign a TQString
* to a KURIFilterData object.
*
* @return an instance of a KURIFilterData object.
diff --git a/tdeio/tdeio/tdefilemetainfo.h b/tdeio/tdeio/tdefilemetainfo.h
index 08649ae1d..e0371c7dd 100644
--- a/tdeio/tdeio/tdefilemetainfo.h
+++ b/tdeio/tdeio/tdefilemetainfo.h
@@ -1643,7 +1643,7 @@ private:
* supported and which groups and items are provided for it, you can ask
* the KFileMetainfoProvider for it.
**/
-class TDEIO_EXPORT KFileMetaInfoProvider: private QObject
+class TDEIO_EXPORT KFileMetaInfoProvider: private TQObject
{
friend class KFilePlugin;
diff --git a/tdeio/tdeio/kacl.h b/tdeio/tdeio/kacl.h
index f581f7a8e..3b96f8dfb 100644
--- a/tdeio/tdeio/kacl.h
+++ b/tdeio/tdeio/kacl.h
@@ -23,12 +23,12 @@
#include <sys/types.h>
#include <tdeio/global.h>
-typedef QPair<TQString, unsigned short> ACLUserPermissions;
+typedef TQPair<TQString, unsigned short> ACLUserPermissions;
typedef TQValueList<ACLUserPermissions> ACLUserPermissionsList;
typedef TQValueListIterator<ACLUserPermissions> ACLUserPermissionsIterator;
typedef TQValueListConstIterator<ACLUserPermissions> ACLUserPermissionsConstIterator;
-typedef QPair<TQString, unsigned short> ACLGroupPermissions;
+typedef TQPair<TQString, unsigned short> ACLGroupPermissions;
typedef TQValueList<ACLGroupPermissions> ACLGroupPermissionsList;
typedef TQValueListIterator<ACLGroupPermissions> ACLGroupPermissionsIterator;
typedef TQValueListConstIterator<ACLGroupPermissions> ACLGroupPermissionsConstIterator;
@@ -146,7 +146,7 @@ public:
bool setNamedUserPermissions( const TQString& name, unsigned short );
/** Returns the list of all group permission entries. Each entry consists
* of a name/permissions pair. This is a QPair, therefore access is provided
* via the .first and .next members.
* @return the list of all group permission entries. */
ACLUserPermissionsList allUserPermissions() const;
@@ -170,7 +170,7 @@ public:
bool setNamedGroupPermissions( const TQString& name, unsigned short );
/** Returns the list of all group permission entries. Each entry consists
* of a name/permissions pair. This is a QPair, therefor access is provided
* via the .first and .next members.
* @return the list of all group permission entries. */
@@ -146,7 +146,7 @@ public:
bool setNamedUserPermissions( const TQString& name, unsigned short );
/** Returns the list of all group permission entries. Each entry consists
- * of a name/permissions pair. This is a QPair, therefore access is provided
+ * of a name/permissions pair. This is a TQPair, therefore access is provided
* via the .first and .next members.
* @return the list of all group permission entries. */
@@ -170,7 +170,7 @@ public:
bool setNamedGroupPermissions( const TQString& name, unsigned short );
/** Returns the list of all group permission entries. Each entry consists
- * of a name/permissions pair. This is a QPair, therefor access is provided
+ * of a name/permissions pair. This is a TQPair, therefor access is provided
* via the .first and .next members.
* @return the list of all group permission entries. */